/****************************************************************************
** Meta object code from reading C++ file 'window.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../layer-shell-qt-6.7.3/src/interfaces/window.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12LayerShellQt6WindowE_t {};
} // unnamed namespace

template <> constexpr inline auto LayerShellQt::Window::qt_create_metaobjectdata<qt_meta_tag_ZN12LayerShellQt6WindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LayerShellQt::Window",
        "anchorsChanged",
        "",
        "exclusionZoneChanged",
        "exclusiveEdgeChanged",
        "marginsChanged",
        "desiredSizeChanged",
        "keyboardInteractivityChanged",
        "layerChanged",
        "wantsToBeOnActiveScreenChanged",
        "screenChanged",
        "anchors",
        "Anchors",
        "scope",
        "margins",
        "QMargins",
        "exclusionZone",
        "layer",
        "Layer",
        "keyboardInteractivity",
        "KeyboardInteractivity",
        "activateOnShow",
        "wantsToBeOnActiveScreen",
        "screen",
        "QScreen*",
        "screenConfiguration",
        "ScreenConfiguration",
        "Anchor",
        "AnchorNone",
        "AnchorTop",
        "AnchorBottom",
        "AnchorLeft",
        "AnchorRight",
        "LayerBackground",
        "LayerBottom",
        "LayerTop",
        "LayerOverlay",
        "KeyboardInteractivityNone",
        "KeyboardInteractivityExclusive",
        "KeyboardInteractivityOnDemand",
        "ScreenFromQWindow",
        "ScreenFromCompositor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'anchorsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusionZoneChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusiveEdgeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desiredSizeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardInteractivityChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layerChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wantsToBeOnActiveScreenChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'anchors'
        QtMocHelpers::PropertyData<Anchors>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'scope'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'margins'
        QtMocHelpers::PropertyData<QMargins>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'exclusionZone'
        QtMocHelpers::PropertyData<qint32>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'layer'
        QtMocHelpers::PropertyData<enum Layer>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'keyboardInteractivity'
        QtMocHelpers::PropertyData<enum KeyboardInteractivity>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'activateOnShow'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'wantsToBeOnActiveScreen'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'screen'
        QtMocHelpers::PropertyData<QScreen*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'screenConfiguration'
        QtMocHelpers::PropertyData<enum ScreenConfiguration>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Anchors'
        QtMocHelpers::EnumData<Anchors>(12, 27, QMC::EnumIsFlag).add({
            {   28, Anchor::AnchorNone },
            {   29, Anchor::AnchorTop },
            {   30, Anchor::AnchorBottom },
            {   31, Anchor::AnchorLeft },
            {   32, Anchor::AnchorRight },
        }),
        // enum 'Layer'
        QtMocHelpers::EnumData<enum Layer>(18, 18, QMC::EnumFlags{}).add({
            {   33, Layer::LayerBackground },
            {   34, Layer::LayerBottom },
            {   35, Layer::LayerTop },
            {   36, Layer::LayerOverlay },
        }),
        // enum 'KeyboardInteractivity'
        QtMocHelpers::EnumData<enum KeyboardInteractivity>(20, 20, QMC::EnumFlags{}).add({
            {   37, KeyboardInteractivity::KeyboardInteractivityNone },
            {   38, KeyboardInteractivity::KeyboardInteractivityExclusive },
            {   39, KeyboardInteractivity::KeyboardInteractivityOnDemand },
        }),
        // enum 'ScreenConfiguration'
        QtMocHelpers::EnumData<enum ScreenConfiguration>(26, 26, QMC::EnumFlags{}).add({
            {   40, ScreenConfiguration::ScreenFromQWindow },
            {   41, ScreenConfiguration::ScreenFromCompositor },
        }),
    };
    return QtMocHelpers::metaObjectData<Window, qt_meta_tag_ZN12LayerShellQt6WindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LayerShellQt::Window::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LayerShellQt6WindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LayerShellQt6WindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12LayerShellQt6WindowE_t>.metaTypes,
    nullptr
} };

void LayerShellQt::Window::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Window *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->anchorsChanged(); break;
        case 1: _t->exclusionZoneChanged(); break;
        case 2: _t->exclusiveEdgeChanged(); break;
        case 3: _t->marginsChanged(); break;
        case 4: _t->desiredSizeChanged(); break;
        case 5: _t->keyboardInteractivityChanged(); break;
        case 6: _t->layerChanged(); break;
        case 7: _t->wantsToBeOnActiveScreenChanged(); break;
        case 8: _t->screenChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::anchorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::exclusionZoneChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::exclusiveEdgeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::marginsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::desiredSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::keyboardInteractivityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::layerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::wantsToBeOnActiveScreenChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Window::*)()>(_a, &Window::screenChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::assignFlags<Anchors>(_v, _t->anchors()); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        case 2: *reinterpret_cast<QMargins*>(_v) = _t->margins(); break;
        case 3: *reinterpret_cast<qint32*>(_v) = _t->exclusionZone(); break;
        case 4: *reinterpret_cast<enum Layer*>(_v) = _t->layer(); break;
        case 5: *reinterpret_cast<enum KeyboardInteractivity*>(_v) = _t->keyboardInteractivity(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->activateOnShow(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->wantsToBeOnActiveScreen(); break;
        case 8: *reinterpret_cast<QScreen**>(_v) = _t->screen(); break;
        case 9: *reinterpret_cast<enum ScreenConfiguration*>(_v) = _t->screenConfiguration(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAnchors(*reinterpret_cast<Anchors*>(_v)); break;
        case 1: _t->setScope(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setMargins(*reinterpret_cast<QMargins*>(_v)); break;
        case 3: _t->setExclusiveZone(*reinterpret_cast<qint32*>(_v)); break;
        case 4: _t->setLayer(*reinterpret_cast<enum Layer*>(_v)); break;
        case 5: _t->setKeyboardInteractivity(*reinterpret_cast<enum KeyboardInteractivity*>(_v)); break;
        case 6: _t->setActivateOnShow(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setWantsToBeOnActiveScreen(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setScreen(*reinterpret_cast<QScreen**>(_v)); break;
        case 9: _t->setScreenConfiguration(*reinterpret_cast<enum ScreenConfiguration*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LayerShellQt::Window::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LayerShellQt::Window::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LayerShellQt6WindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LayerShellQt::Window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void LayerShellQt::Window::anchorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LayerShellQt::Window::exclusionZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LayerShellQt::Window::exclusiveEdgeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LayerShellQt::Window::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LayerShellQt::Window::desiredSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LayerShellQt::Window::keyboardInteractivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LayerShellQt::Window::layerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void LayerShellQt::Window::wantsToBeOnActiveScreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void LayerShellQt::Window::screenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
