/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_layershell()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<WindowForeign>("org.kde.layershell", 1);
    qmlRegisterEnum<LayerShellQt::Window::Anchors>("LayerShellQt::Window::Anchors");
    qmlRegisterEnum<LayerShellQt::Window::Anchor>("LayerShellQt::Window::Anchor");
    qmlRegisterEnum<LayerShellQt::Window::Layer>("LayerShellQt::Window::Layer");
    qmlRegisterEnum<LayerShellQt::Window::KeyboardInteractivity>("LayerShellQt::Window::KeyboardInteractivity");
    qmlRegisterEnum<LayerShellQt::Window::ScreenConfiguration>("LayerShellQt::Window::ScreenConfiguration");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.layershell", 1, 0);
}

static const QQmlModuleRegistration orgkdelayershellRegistration("org.kde.layershell", qml_register_types_org_kde_layershell);
